package logic

import (
	"errors"
	"fusenapi/model/gmodel"
	"fusenapi/utils/auth"
	"fusenapi/utils/basic"

	"context"

	"fusenapi/server/ldap-admin/internal/svc"
	"fusenapi/server/ldap-admin/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
	"gorm.io/gorm"
)

type DeleteLdapGroupLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewDeleteLdapGroupLogic(ctx context.Context, svcCtx *svc.ServiceContext) *DeleteLdapGroupLogic {
	return &DeleteLdapGroupLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

// 处理进入前逻辑w,r
// func (l *DeleteLdapGroupLogic) BeforeLogic(w http.ResponseWriter, r *http.Request) {
// }

func (l *DeleteLdapGroupLogic) DeleteLdapGroup(req *types.DeleteLdapGroupReq, userinfo *auth.UserInfo) (resp *basic.Response) {
	// 返回值必须调用Set重新返回, resp可以空指针调用 resp.SetStatus(basic.CodeOK, data)
	// userinfo 传入值时, 一定不为null
	resLdapGroupInfo, err := l.svcCtx.AllModels.LdapGroup.FindOneById(l.ctx, req.Id)
	if err != nil {
		if errors.Is(err, gorm.ErrRecordNotFound) {
			basic.CodeServiceErr.Message = "记录不存在"
		} else {
			basic.CodeServiceErr.Message = "系统出错"
		}
		return resp.SetStatus(basic.CodeServiceErr)
	}
	txErr := l.svcCtx.MysqlConn.WithContext(l.ctx).Transaction(func(tx *gorm.DB) error {
		//删除权限组、权限组相关
		resLdapGroupDel := tx.Delete(&resLdapGroupInfo)
		if resLdapGroupDel.Error != nil {
			return resLdapGroupDel.Error
		}
		resLdapUserGroupDel := tx.Where("group_id = ?", resLdapGroupInfo.Id).Delete(&gmodel.LdapUserGroup{})
		if resLdapUserGroupDel.Error != nil {
			return resLdapUserGroupDel.Error
		}
		resLdapGroupMenusDel := tx.Where("group_id = ?", resLdapGroupInfo.Id).Delete(&gmodel.LdapGroupMenus{})
		if resLdapGroupMenusDel.Error != nil {
			return resLdapGroupMenusDel.Error
		}
		return nil
	})
	if txErr != nil {
		l.Logger.Errorf("delete ldap group error: %v", txErr)
		basic.CodeServiceErr.Message = "删除失败"
		return resp.SetStatus(basic.CodeServiceErr)
	}
	return resp.SetStatus(basic.CodeOK)
}

// 处理逻辑后 w,r 如:重定向, resp 必须重新处理
// func (l *DeleteLdapGroupLogic) AfterLogic(w http.ResponseWriter, r *http.Request, resp *basic.Response) {
// // httpx.OkJsonCtx(r.Context(), w, resp)
// }
